#include "mnemos.com"
#include "mnemos.cyr"
#include "mnemos.gen"
#include "mnemos.grk"
#include "mnemos.rfc"
#include "mnemos.sup"
#include "mnemos.tex"
#include "mnemos.www"
